@@ -14,5 +14,7 @@ Copyright 2012-2014 Diffeo, Inc.
 from __future__ import absolute_import
 
 from pytest_diffeo.args import pytest_addoption, pytest_configure, \
-    pytest_runtest_setup, redis_address
+    pytest_runtest_setup, \
+    pytest_runtest_teardown, \
+    redis_address
 from pytest_diffeo.namespace import make_namespace_string, namespace_string
